@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import typing as t
 
 from .azure_pipelines import azure_main
@@ -5,7 +7,7 @@ from .azure_pipelines import azure_main
 DataT = t.Union[dict, list]
 TransformT = t.Callable[[DataT], DataT]
 
-TRANFORM_LIBRARY: t.Dict[str, TransformT] = {
+TRANFORM_LIBRARY: dict[str, t.Callable[[dict | list], dict | list]] = {
     "azure-pipelines": azure_main,
 }
 
